( cd usr/bin ; rm -rf vmake )
( cd usr/bin ; ln -sf pmake vmake )
( cd usr/share/mk ; rm -rf sys-9000-720.mk )
( cd usr/share/mk ; ln -sf sys-snake.mk sys-9000-720.mk )
( cd usr/share/mk ; rm -rf sys-9000-730.mk )
( cd usr/share/mk ; ln -sf sys-snake.mk sys-9000-730.mk )
( cd usr/share/mk ; rm -rf sys-IP19.mk )
( cd usr/share/mk ; ln -sf sys-iris.mk sys-IP19.mk )
( cd usr/share/mk ; rm -rf sys-IP20.mk )
( cd usr/share/mk ; ln -sf sys-iris.mk sys-IP20.mk )
( cd usr/share/mk ; rm -rf sys-IP22.mk )
( cd usr/share/mk ; ln -sf sys-iris.mk sys-IP22.mk )
( cd usr/share/mk ; rm -rf sys-IP25.mk )
( cd usr/share/mk ; ln -sf sys-iris.mk sys-IP25.mk )
( cd usr/share/mk ; rm -rf sys-IP7.mk )
( cd usr/share/mk ; ln -sf sys-iris.mk sys-IP7.mk )
( cd usr/share/mk ; rm -rf sys-i486.mk )
( cd usr/share/mk ; ln -sf sys-i386.mk sys-i486.mk )
( cd usr/share/mk ; rm -rf sys-i586.mk )
( cd usr/share/mk ; ln -sf sys-i386.mk sys-i586.mk )
( cd usr/share/mk ; rm -rf sys-i686.mk )
( cd usr/share/mk ; ln -sf sys-i386.mk sys-i686.mk )
( cd usr/share/mk ; rm -rf sys-i786.mk )
( cd usr/share/mk ; ln -sf sys-i386.mk sys-i786.mk )
